@@ -1,5 +1,5 @@
 /*
-Copyright 2017 the Velero contributors.
+Copyright 2017, 2020 the Velero contributors.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -341,11 +341,12 @@ func TestBackupSyncControllerRun(t *testing.T) {
 				client.VeleroV1(),
 				client.VeleroV1(),
 				client.VeleroV1(),
-				sharedInformers.Velero().V1().Backups(),
-				sharedInformers.Velero().V1().BackupStorageLocations(),
-				sharedInformers.Velero().V1().PodVolumeBackups(),
+				sharedInformers.Velero().V1().Backups().Lister(),
+				sharedInformers.Velero().V1().BackupStorageLocations().Lister(),
 				time.Duration(0),
 				test.namespace,
+				nil, // csiSnapshotClient
+				nil, // kubeClient
 				"",
 				func(logrus.FieldLogger) clientmgmt.Manager { return pluginManager },
 				velerotest.NewLogger(),
@@ -565,11 +566,12 @@ func TestDeleteOrphanedBackups(t *testing.T) {
 				client.VeleroV1(),
 				client.VeleroV1(),
 				client.VeleroV1(),
-				sharedInformers.Velero().V1().Backups(),
-				sharedInformers.Velero().V1().BackupStorageLocations(),
-				sharedInformers.Velero().V1().PodVolumeBackups(),
+				sharedInformers.Velero().V1().Backups().Lister(),
+				sharedInformers.Velero().V1().BackupStorageLocations().Lister(),
 				time.Duration(0),
 				test.namespace,
+				nil, // csiSnapshotClient
+				nil, // kubeClient
 				"",
 				nil, // new plugin manager func
 				velerotest.NewLogger(),
@@ -657,11 +659,12 @@ func TestStorageLabelsInDeleteOrphanedBackups(t *testing.T) {
 				client.VeleroV1(),
 				client.VeleroV1(),
 				client.VeleroV1(),
-				sharedInformers.Velero().V1().Backups(),
-				sharedInformers.Velero().V1().BackupStorageLocations(),
-				sharedInformers.Velero().V1().PodVolumeBackups(),
+				sharedInformers.Velero().V1().Backups().Lister(),
+				sharedInformers.Velero().V1().BackupStorageLocations().Lister(),
 				time.Duration(0),
 				test.namespace,
+				nil, // csiSnapshotClient
+				nil, // kubeClient
 				"",
 				nil, // new plugin manager func
 				velerotest.NewLogger(),
